##  Adding Notes to Slides
To provide more context and details on each report and diagram, you can add notes to slides (except for the intro slide). Notes are also displayed when you preview or start the presentation. You can show or hide these notes as needed, ensuring clarity and focus during your presentation.
To add notes to a slide, select it, click Edit notes in the right-side panel, then enter your notes in the text field that appears.
![Adding Notes to a Slide](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756b62a7a441014a576e5c55a61859f_LowRes.gif)
Adding Notes to a Slide
To show or hide notes for a specific slide, select the slide in the left-side pane, then enable or disable the Notes toggle as needed.
![Notes Toggle on the Slide Preview](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741a1767a4410149d8dcc9e6bf48302_LowRes.png)
Notes Toggle on the Slide Preview
